==> wordle-1.0.tar.gz: wordle/builtin_tree.c <==
/*
    This file is part of Wordle Solver.
    Copyright (C) 2022  Laurent Poirrier

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published
    by the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "tree.h"
#include "builtin_tree.h"

// ****************************************************************************
// 
// ****************************************************************************
#define tree_nodes regular_tree_nodes
//#include "data/ar_d6k2.i"
#include "data/ar_d5k200.i"
// depth 4 [ongoing]
// lb = 3 (ar_d3a)
static const node_index regular_tree_root = TREE_ROOT;
static const node_index regular_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes cheat_tree_nodes
#include "data/cr_d4k5.i" // 7s
// lb = 3 (cr_d3a)
static const node_index cheat_tree_root = TREE_ROOT;
static const node_index cheat_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes hard_tree_nodes
#include "data/ah_d13k3.i" // 8s
static const node_index hard_tree_root = TREE_ROOT;
static const node_index hard_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes cheat_hard_tree_nodes
//#include "data/ch_d5k3.i"
#include "data/ch_d4k200.i" // 29s x10
// lb = 3 (ch_d3a ongoing)
static const node_index cheat_hard_tree_root = TREE_ROOT;
static const node_index cheat_hard_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE


// place here tree for unknown game mode
//#include "tmp.i"

// fallback tree for unknown game mode
#ifndef TREE_SIZE
#define TREE_SIZE 1
#define TREE_ROOT 0
static node tree_nodes[1] = { { HASH_ANY, 0, 0, NODE_NONE, NODE_NONE } };
#endif



// ****************************************************************************
// 
// ****************************************************************************
void tree_builtin_get(node_index *count_r, node_index *root_r, node **nodes_r,
	int flags)
{
	node_index count = TREE_SIZE;
	node_index root = TREE_ROOT;
	node *nodes = tree_nodes;
	
	if (flags == GAME_REGULAR) {
		count = regular_tree_size;
		root = regular_tree_root;
		nodes = regular_tree_nodes;
	} else if (flags == GAME_CHEAT) {
		count = cheat_tree_size;
		root = cheat_tree_root;
		nodes = cheat_tree_nodes;
	} else if (flags == GAME_HARD) {
		count = hard_tree_size;
		root = hard_tree_root;
		nodes = hard_tree_nodes;
	} else if (flags == (GAME_CHEAT | GAME_HARD)) {
		count = cheat_hard_tree_size;
		root = cheat_hard_tree_root;
		nodes = cheat_hard_tree_nodes;
	} else {
		fprintf(stderr, "Warning: no builtin tree for game mode %d.\n"
			"Using placeholder tree.\n",
			flags);
	}

	if (count_r)
		*count_r = count;
	if (root_r)
		*root_r = root;
	if (nodes_r)
		*nodes_r = nodes;
}

// ****************************************************************************
// 
// ****************************************************************************

==> wordle-2.0.tar.gz: wordle/builtin_tree.c <==
/*
    This file is part of Wordle Solver.
    Copyright (C) 2022  Laurent Poirrier

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published
    by the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "tree.h"
#include "builtin_tree.h"

// ****************************************************************************
// 
// ****************************************************************************
#define tree_nodes regular_tree_nodes

#ifdef NYT
#include "data/nar_d5k200.i"
#else
//#include "data/ar_d6k2.i"
//#include "data/ar_d5k200.i"
#include "data/ar_d5k400_larks.i"
// depth 4 (never completed)
// lb = 3 (ar_d3a)
#endif

static const node_index regular_tree_root = TREE_ROOT;
static const node_index regular_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes cheat_tree_nodes

#ifdef NYT
#include "data/ncr_d4k5.i" // 6s
#else
//#include "data/cr_d4k5.i" // 7s
#include "data/gcr_selby.i"
// lb = 3 (cr_d3a)
#endif

static const node_index cheat_tree_root = TREE_ROOT;
static const node_index cheat_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes hard_tree_nodes

#ifdef NYT
#include "data/nah_d13k4.i" // 19s
#else
#include "data/ah_d13k3.i" // 8s
#endif

static const node_index hard_tree_root = TREE_ROOT;
static const node_index hard_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE

#define tree_nodes cheat_hard_tree_nodes

#ifdef NYT
#include "data/nch_d5k5.i" // 4s
#else
//#include "data/ch_d5k3.i"
//#include "data/ch_d4k200.i" // 29s x10
#include "data/gch_selby.i"
// lb = 3 (ch_d3a ongoing)
#endif

static const node_index cheat_hard_tree_root = TREE_ROOT;
static const node_index cheat_hard_tree_size = TREE_SIZE;

#undef tree_nodes
#undef TREE_ROOT
#undef TREE_SIZE


// place here tree for unknown game mode
//#include "tmp.i"

// fallback tree for unknown game mode
#ifndef TREE_SIZE
#define TREE_SIZE 1
#define TREE_ROOT 0
static node tree_nodes[1] = { { HASH_ANY, 0, 0, NODE_NONE, NODE_NONE } };
#endif



// ****************************************************************************
// 
// ****************************************************************************
void tree_builtin_get(node_index *count_r, node_index *root_r, node **nodes_r,
	int flags)
{
	node_index count = TREE_SIZE;
	node_index root = TREE_ROOT;
	node *nodes = tree_nodes;
	
	if (flags == GAME_REGULAR) {
		count = regular_tree_size;
		root = regular_tree_root;
		nodes = regular_tree_nodes;
	} else if (flags == GAME_CHEAT) {
		count = cheat_tree_size;
		root = cheat_tree_root;
		nodes = cheat_tree_nodes;
	} else if (flags == GAME_HARD) {
		count = hard_tree_size;
		root = hard_tree_root;
		nodes = hard_tree_nodes;
	} else if (flags == (GAME_CHEAT | GAME_HARD)) {
		count = cheat_hard_tree_size;
		root = cheat_hard_tree_root;
		nodes = cheat_hard_tree_nodes;
	} else {
		fprintf(stderr, "Warning: no builtin tree for game mode %d.\n"
			"Using placeholder tree.\n",
			flags);
	}

	if (count_r)
		*count_r = count;
	if (root_r)
		*root_r = root;
	if (nodes_r)
		*nodes_r = nodes;
}

// ****************************************************************************
// 
// ****************************************************************************
